@@ -1,4 +1,4 @@
-//$Id: app-res.cc,v 1.3 2001/03/09 17:11:21 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.4 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -17,6 +17,7 @@
  */
 
 #include "app-res.h"
+#include <gnome-xml/xmlmemory.h>
 
 using namespace Guikachu;
 
@@ -65,13 +66,13 @@ bool Resources::Application::load (xmlDocPtr doc,
     if (xml_iconname)
     {
 	iconname = xml_iconname;
-	g_free (xml_iconname);
+	xmlFree (xml_iconname);
     }
 
     if (xml_version)
     {
 	version = xml_version;
-	g_free (xml_version);
+	xmlFree (xml_version);
     }
     
     changed ();
