@@ -1,4 +1,4 @@
-//$Id: app-res.h,v 1.1 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: app-res.h,v 1.2 2001/03/11 14:14:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,6 +33,7 @@ namespace Guikachu
 #include <string>
 
 #include "app-win.h"
+#include "resource.h"
 
 namespace Guikachu
 {
@@ -40,10 +41,6 @@ namespace Guikachu
     {
 	class Application
 	{
-	    string iconname;
-	    string version;
-	    string vendor;
-
 	    GUI::AppWindow *gui;
 
 	public:
@@ -52,15 +49,10 @@ namespace Guikachu
 	    SigC::Signal0<void> changed;
 
 	    void show_ui ();
-	    
-	    string get_iconname () const { return iconname; };
-	    void set_iconname (const string& iconname_) { iconname = iconname_; changed (); };
 
-	    string get_version () const { return version; };
-	    void set_version (const string& version_) { version = version_; changed (); };
-
-	    string get_vendor () const { return vendor; };
-	    void set_vendor (const string& vendor_) { vendor = vendor_; changed (); };
+	    GUIKACHU_RESOURCE_PROP(iconname, string);
+	    GUIKACHU_RESOURCE_PROP(version,  string);
+	    GUIKACHU_RESOURCE_PROP(vendor,   string);
 	    
 	private:
 	    bool load (xmlDocPtr xml_doc, xmlNodePtr node);
