@@ -1,4 +1,4 @@
-//$Id: app-win.cc,v 1.1 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: app-win.cc,v 1.2 2001/04/03 16:02:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,7 +26,8 @@
 using namespace Guikachu;
 
 GUI::AppWindow::AppWindow (Resources::Application *res_):
-    res (res_)
+    res (res_),
+    update_block (false)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", NULL);
 
@@ -40,20 +41,9 @@ GUI::AppWindow::AppWindow (Resources::Application *res_):
     version_entry =  wrap (GTK_ENTRY (glade_xml_get_widget (gui, "app_version")));
     vendor_entry =   wrap (GTK_ENTRY (glade_xml_get_widget (gui, "app_vendor")));
     
-    iconname_entry->activate.connect
-	(bind (slot (this, &AppWindow::iconname_entry_cb), (GdkEventFocus*) 0));
-    iconname_entry->focus_out_event.connect
-	(retbind (slot (this, &AppWindow::iconname_entry_cb), 0));
-
-    version_entry->activate.connect
-	(bind (slot (this, &AppWindow::version_entry_cb), (GdkEventFocus*) 0));
-    version_entry->focus_out_event.connect
-	(retbind (slot (this, &AppWindow::version_entry_cb), 0));
-
-    vendor_entry->activate.connect
-	(bind (slot (this, &AppWindow::vendor_entry_cb), (GdkEventFocus*) 0));
-    vendor_entry->focus_out_event.connect
-	(retbind (slot (this, &AppWindow::vendor_entry_cb), 0));
+    iconname_entry->changed.connect (slot (this, &AppWindow::iconname_entry_cb));
+    version_entry->changed.connect  (slot (this, &AppWindow::version_entry_cb));
+    vendor_entry->changed.connect   (slot (this, &AppWindow::vendor_entry_cb));
     
     res->changed.connect (slot (this, &AppWindow::update));
     update ();
@@ -79,6 +69,8 @@ void GUI::AppWindow::show ()
 
 void GUI::AppWindow::update ()
 {
+    update_block = true;
+    
     gchar *title_buf = g_strdup_printf (_("Application: %s"), res->get_iconname ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
@@ -86,19 +78,36 @@ void GUI::AppWindow::update ()
     iconname_entry->set_text (res->get_iconname ());
     version_entry->set_text (res->get_version ());
     vendor_entry->set_text (res->get_vendor ());
+
+    update_block = false;
 }
 
-void GUI::AppWindow::iconname_entry_cb (GdkEventFocus *e)
+void GUI::AppWindow::iconname_entry_cb ()
 {
+    if (update_block)
+	return;
+
+    int old_pos = iconname_entry->get_position ();
     res->set_iconname (iconname_entry->get_text ());
+    iconname_entry->set_position (old_pos);
 }
 
-void GUI::AppWindow::version_entry_cb (GdkEventFocus *e)
+void GUI::AppWindow::version_entry_cb ()
 {
+    if (update_block)
+	return;
+
+    int saved_pos = version_entry->get_position ();
     res->set_version (version_entry->get_text ());
+    version_entry->set_position (saved_pos);
 }
 
-void GUI::AppWindow::vendor_entry_cb (GdkEventFocus *e)
+void GUI::AppWindow::vendor_entry_cb ()
 {
+    if (update_block)
+	return;
+
+    int old_pos = vendor_entry->get_position ();
     res->set_vendor (vendor_entry->get_text ());
+    vendor_entry->set_position (old_pos);
 }
