@@ -1,4 +1,4 @@
-//$Id: app-win.h,v 1.1 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: app-win.h,v 1.2 2001/04/03 16:02:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -57,9 +57,11 @@ namespace Guikachu
 	private:
 	    int delete_event_impl (GdkEventAny *e);
 	    void update ();
-	    void iconname_entry_cb (GdkEventFocus *e);
-	    void version_entry_cb  (GdkEventFocus *e);
-	    void vendor_entry_cb   (GdkEventFocus *e);
+	    bool update_block;
+	    
+	    void iconname_entry_cb ();
+	    void version_entry_cb  ();
+	    void vendor_entry_cb   ();
 	};
     };
 };
