@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.7 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.11 2001/04/17 17:20:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,18 +24,22 @@
 #include <gtk--/menu.h>
 #include <gnome--/dialog.h>
 #include <sigc++/retbind.h>
-#include "resource-combo.h"
+#include "argumentsink.h"
 
 using namespace Guikachu;
 
-GUI::DialogWindow::DialogWindow (Guikachu::Resources::Dialog *res_):
+GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     res (res_),
-    help_combo (Resources::RESOURCE_STRING),
+    help_combo (Resources::RESOURCE_STRING,
+		SigC::slot (res, &Resources::Dialog::get_help_id),
+		SigC::slot (res, &Resources::Dialog::set_help_id),
+		res->changed),
     update_block (true)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);
 
     using namespace Gtk;
+    using namespace SigC;
     
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_dialog")));
     window->delete_event.connect (slot (this, &DialogWindow::delete_event_impl));
@@ -50,20 +54,16 @@ GUI::DialogWindow::DialogWindow (Guikachu::Resources::Dialog *res_):
     text_entry->set_word_wrap (true);
 
     // Set up callbacks
-    id_entry->activate.connect (bind (
-	slot (this, &DialogWindow::id_entry_cb), (GdkEventFocus*) 0));
-    id_entry->focus_out_event.connect (retbind (
-	slot (this, &DialogWindow::id_entry_cb), 0));
+    id_entry->activate.connect (slot (this, &DialogWindow::id_entry_cb));
+    id_entry->focus_out_event.connect (
+	hide<int, GdkEventFocus*> (retbind (slot (this, &DialogWindow::id_entry_cb),0)));
 
-    title_entry->activate.connect (bind (
-	slot (this, &DialogWindow::title_entry_cb), (GdkEventFocus*) 0));
-    title_entry->focus_out_event.connect (retbind (
-	slot (this, &DialogWindow::title_entry_cb), 0));
+    title_entry->activate.connect (slot (this, &DialogWindow::id_entry_cb));
+    title_entry->focus_out_event.connect (
+	hide<int, GdkEventFocus*> (retbind (slot (this, &DialogWindow::title_entry_cb),0)));
 
     text_entry->changed.connect (slot (this, &DialogWindow::text_entry_cb));
 
-    help_combo.changed.connect (slot (this, &DialogWindow::help_combo_cb));
-    
     // Dialog type dropdown
     Menu *type_menu = new Menu ();
 
@@ -142,7 +142,6 @@ void GUI::DialogWindow::update ()
     text_entry->insert (res->get_text ());
 
     type_combo->set_history (res->get_dialog_type ());
-    help_combo.set_value (res->get_help_id ());
     
     vector<string> buttons = res->get_buttons ();
     vector<string>::iterator i;
@@ -170,12 +169,12 @@ void GUI::DialogWindow::update ()
     update_block = false;
 }
 
-void GUI::DialogWindow::id_entry_cb (GdkEventFocus *e)
+void GUI::DialogWindow::id_entry_cb ()
 {
     res->set_id (id_entry->get_text ());
 }
 
-void GUI::DialogWindow::title_entry_cb (GdkEventFocus *e)
+void GUI::DialogWindow::title_entry_cb ()
 {
     res->set_title (title_entry->get_text ());
 }
@@ -185,7 +184,9 @@ void GUI::DialogWindow::text_entry_cb ()
     if (update_block)
 	return;
 
+    int saved_pos = text_entry->get_position ();
     res->set_text (text_entry->get_chars (0, text_entry->get_length ()));
+    gtk_editable_set_position (GTK_EDITABLE (text_entry->gtkobj ()), saved_pos);
 }
 
 void GUI::DialogWindow::type_menu_cb (Resources::DialogType type)
@@ -193,14 +194,6 @@ void GUI::DialogWindow::type_menu_cb (Resources::DialogType type)
     res->set_dialog_type (type);
 }
 
-void GUI::DialogWindow::help_combo_cb (const string& help_id)
-{
-    if (update_block)
-	return;
-
-    res->set_help_id (help_id);
-}
-
 void GUI::DialogWindow::dialog_add_cb (string name)
 {
     if (name != "")
@@ -213,6 +206,16 @@ void GUI::DialogWindow::dialog_add_cb (string name)
 
 void GUI::DialogWindow::button_add_cb ()
 {
+    bool selection_saved = false;
+    unsigned int index = 0;
+    
+    if (button_list->selection ().size () != 0)
+    {
+	Gtk::List::SelectionList::iterator sel = button_list->selection ().begin ();  
+	index = GPOINTER_TO_UINT ((*sel)->get_user_data ());
+	selection_saved = true;
+    }
+    
     Gnome::Dialog *dialog = Gnome::Dialogs::request
 	(*window, false,
 	 _("Enter name of new button"),
@@ -220,6 +223,9 @@ void GUI::DialogWindow::button_add_cb ()
 	 slot (this, &DialogWindow::dialog_add_cb));
 
     dialog->run_and_close ();
+
+    if (selection_saved)
+	button_list->select_item (index);
 }
 
 void GUI::DialogWindow::button_remove_cb ()
@@ -245,6 +251,8 @@ void GUI::DialogWindow::button_default_cb ()
     unsigned int index = GPOINTER_TO_UINT ((*sel)->get_user_data ());
 
     res->set_default_button (index);
+
+    button_list->select_item (index);
 }
 
 void GUI::DialogWindow::button_up_cb ()
