@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.4 2001/03/21 17:09:44 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.8 2001/04/22 13:03:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,14 +42,16 @@ Form::Form (Resources::Form *res_,
     widget_group (0)
 {
     using namespace SigC;
-    
-    new Gnome::CanvasRect ((*canvas->root ()),
-			   "width_pixels", 0,
-			   "x1",   0.0, "y1",   0.0,
-			   "x2", 160.0, "y2", 160.0,
-			   "fill_color", GUIKACHU_BGC,
-			   NULL);
 
+    Gnome::CanvasItem *background;
+    
+    background = new Gnome::CanvasRect ((*canvas->root ()),
+					"width_pixels", 0,
+					"x1",   0.0, "y1",   0.0,
+					"x2", 160.0, "y2", 160.0,
+					"fill_color", GUIKACHU_BGC,
+					NULL);
+    
     group = new Gnome::CanvasGroup (*(canvas->root ()), 0, 0);
     group->event.connect (slot (this, &Form::canvas_event_cb));
     
@@ -78,8 +80,8 @@ void Form::update ()
 	delete widget_group;
     widget_group = new Gnome::CanvasGroup (*group, 0, 0);
     
-    set<Resources::Widgets::Widget*> wset = res->get_widgets ();
-    for (set<Resources::Widgets::Widget*>::iterator i = wset.begin ();
+    set<Widgets::Widget*> wset = res->get_widgets ();
+    for (set<Widgets::Widget*>::iterator i = wset.begin ();
 	 i != wset.end (); i++)
     {
 	(*i)->get_canvas_item (this);
@@ -93,10 +95,37 @@ Gtk::Widget* Form::get_editor ()
 
 int Form::canvas_event_cb (GdkEvent *e)
 {
+    static bool button_down = false;
+    static double x_orig, y_orig;
+    
+    double x = e->button.x;
+    double y = e->button.y;
+    
+    group->w2i (x, y);
+	
+    if (e->type == GDK_BUTTON_RELEASE &&
+	e->button.button == 1)
+    {
+	button_down = false;
+    }
+
+#if 0
+    if (e->type == GDK_MOTION_NOTIFY && button_down)
+    {
+	group->move (x - x_orig, y - y_orig);
+    }
+#endif
+
+    
     if ((e->type == GDK_BUTTON_PRESS) &&
 	(e->button.button == 1))
-	win->show_property_editor (get_editor ());
-    
+    {
+	x_orig = x;
+	y_orig = y;
+	button_down = true;
+
+	show_editor ();
+    }
     
     return false;
 }
@@ -106,6 +135,15 @@ void Form::draw_frame ()
     if (frame_group)
 	delete frame_group;
     frame_group = new Gnome::CanvasGroup (*group, 0, 0);
+
+    new Gnome::CanvasRect (*frame_group,
+			   "width_units", 1.0,
+			   "x1", (double) -1,
+			   "y1", (double) -1,
+			   "x2", (double) res->get_width (),
+			   "y2", (double) res->get_height (),
+			   "fill_color", NULL,
+			   0);
     
     if (res->get_modal ())
 	draw_frame_modal ();
