@@ -1,4 +1,4 @@
-//$Id: label-prop.h,v 1.3 2001/03/26 20:57:37 cactus Exp $ -*- c++ -*-
+//$Id: label-prop.h,v 1.7 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,14 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_LABEL_PROP_H
 #define GUIKACHU_FORM_EDITOR_LABEL_PROP_H
 
-#include <string>
-#include <iostream>
-#include <sigc++/object.h>
-#include <glade/glade-xml.h>
-
-#include <gtk--/entry.h>
-#include <gtk--/spinbutton.h>
-
 namespace Guikachu
 {
     namespace GUI
@@ -46,36 +38,17 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class LabelProperties: public SigC::Object
+	    class LabelProperties
 	    {
-		Resources::Widgets::Label *res;
+		Widgets::Label    *res;
 		
 		/* Property editor */
-		GladeXML          *gui;
 		Gtk::Widget       *property_editor;
 		
-		Gtk::Entry        *id_entry;
-		Gtk::Entry        *text_entry;
-		
-		Gtk::SpinButton   *font_entry;
-		Gtk::SpinButton   *x_entry, *y_entry;
-		
 	    public:
-		LabelProperties (Resources::Widgets::Label *res);
+		LabelProperties (Widgets::Label *res);
 		~LabelProperties ();
 		Gtk::Widget *get_editor ();
-
-	    private:
-		void update ();
-		bool update_block;
-		
-		void id_entry_cb (GdkEventFocus *e);
-		void text_entry_cb ();
-		
-		void font_cb ();
-		
-		void x_cb ();
-		void y_cb ();
 	    };
 	}
     }
