@@ -1,4 +1,4 @@
-//$Id: label.cc,v 1.5 2001/03/26 22:19:27 cactus Exp $ -*- c++ -*-
+//$Id: label.cc,v 1.13 2001/04/22 14:53:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,8 +24,9 @@
 #include "form-editor.h"
 
 #include <gnome--.h>
+#include <gnome-xml/xmlmemory.h>
 
-using Guikachu::Resources::Widgets::Label;
+using Guikachu::Widgets::Label;
 using namespace Guikachu::GUI::FormEditor;
 
 namespace Guikachu
@@ -34,33 +35,33 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class LabelCanvasItem: public CanvasItem,
-				   public SigC::Object
+	    class LabelCanvasItem: public CanvasItem
 	    {
-		Label              *res;
-		Form               *form;
+		Widgets::Label     *widget;
+		FormEditor::Form   *form;
 		Gnome::CanvasGroup *group;
 	    public:
-		LabelCanvasItem (Label *res,
-				 Form  *form);
+		LabelCanvasItem (Widgets::Label   *widget,
+				 FormEditor::Form *form);
 	    private:
-		int LabelCanvasItem::canvas_event_cb (GdkEvent *e);
 		void update ();
 	    };
 	}
     }
 }
 
-Label::Label (Form *owner_,
+Label::Label (Resources::Form *owner_,
 	      const string& id_):
     text (id_),
     font (0),
-    x (5),
-    y (20)
+    usable (true)
 {
     id = id_;
     owner = owner_;
 
+    x = 5;
+    y = 20;
+
     editor = new LabelProperties (this);
 }
 
@@ -83,6 +84,9 @@ bool Label::load (xmlDocPtr doc,
     bool xml_text_set = false;
     
     gchar *xml_val;
+
+    /* Non-NULL default values */
+    usable = false;
     
 #define XML_HAS_NAME(node, val) (!strcmp ((char*) node->name, val))
     
@@ -90,7 +94,7 @@ bool Label::load (xmlDocPtr doc,
 	if (xml_val)          \
 	{                     \
 	    attr = xml_val;   \
-	    g_free (xml_val); \
+	    xmlFree (xml_val);\
 	}
 
 #define XML_GET_CONTENT(node, attr) \
@@ -102,7 +106,7 @@ bool Label::load (xmlDocPtr doc,
 	if (xml_val)						\
 	{							\
 	    attr = atoi(xml_val);				\
-	    g_free (xml_val);					\
+	    xmlFree (xml_val);					\
 	}
 
     for (curr_node  = node->xmlChildrenNode;
@@ -123,6 +127,13 @@ bool Label::load (xmlDocPtr doc,
 
 	    xml_text_set = true;
 	}
+	else if (XML_HAS_NAME (curr_node, "usable"))
+	{
+	    usable = true;
+	}
+	else
+	    g_warning ("Error parsing `label' widget: "
+		       "unexpected element `%s'", curr_node->name);
     }
 
     changed ();
@@ -144,6 +155,10 @@ void Label::save (xmlNodePtr node) const
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
+    /* Usable */
+    if (usable)
+	xmlNewChild (node, NULL, (xmlChar*) "usable", NULL);
+    
     /* Text and font */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
 			   (xmlChar*) text.c_str ());
@@ -154,56 +169,49 @@ void Label::save (xmlNodePtr node) const
 
 void Label::save_rcp (ostream &ostr) const
 {
-    ostr << "  LABEL \"" << text << "\""
-	 << " ID " << id
-	 << " AT (" << x << " " << y << ")"
-	 << " USABLE"
-	 << " FONT " << font;
+    ostr << "  LABEL \"" << text << "\"" << " ID " << id;
+    ostr << " AT (" << x << " " << y << ")";
+    ostr << " FONT " << font;
+    if (usable)
+	ostr << " USABLE";
     ostr << endl;
 }
 
-LabelCanvasItem::LabelCanvasItem (Label *res_,
-				  Form  *form_):
-    res (res_),
+LabelCanvasItem::LabelCanvasItem (Widgets::Label   *widget_,
+				  FormEditor::Form *form_):
+    CanvasItem (widget_),
+    widget (widget_),
     form (form_),
     group (0)
 {
     using namespace SigC;
     
-    res->changed.connect (slot (this, &LabelCanvasItem::update));
+    widget->changed.connect (slot (this, &LabelCanvasItem::update));
     update ();
 }
 
-int LabelCanvasItem::canvas_event_cb (GdkEvent *e)
-{
-    if ((e->type == GDK_BUTTON_PRESS) &&
-	(e->button.button == 1))
-	;
-//	win->show_property_editor (get_editor ());
-    
-    return false;
-}
-
 void LabelCanvasItem::update ()
 {
-    using namespace SigC;
-    
     if (group)
 	delete group;
-
+    form->get_canvas ()->get_canvas ()->update_now ();
+    
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
+    set_canvas_item (group);
     
-    GdkFont *font = get_font (res->get_font ());
+    GdkFont *font = get_font (widget->get_font ());
     
-    Gnome::CanvasItem *item = new Gnome::CanvasText (*group,
-						     "text", res->get_text ().c_str (),
-						     "font_gdk", font,
-						     "x", (float)res->get_x (),
-						     "y", (float)res->get_y (),
-						     "anchor", GTK_ANCHOR_NW,
-						     "fill_color", GUIKACHU_FGC,
-						     0);
-    item->event.connect (slot (this, &LabelCanvasItem::canvas_event_cb));
+    Gnome::CanvasText *item = new Gnome::CanvasText (*group,
+                                                     "text", widget->get_text ().c_str (),
+                                                     "font_gdk", font,
+                                                     "x", (float)widget->get_x (),
+                                                     "y", (float)widget->get_y (),
+                                                     "anchor", GTK_ANCHOR_NW,
+                                                     0);
+    if (widget->get_usable ())
+        item->set_fill_color (GUIKACHU_FGC);
+    else
+        item->set_fill_color (GUIKACHU_FGC_DISABLED);
     
     gdk_font_unref (font);
 }
