@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.5 2001/03/23 15:14:46 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.10 2001/04/21 13:02:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,9 +18,13 @@
 
 #include "form-res.h"
 
+#include "form-editor/widget.h"
 #include "form-editor/label.h"
+#include "form-editor/button.h"
+#include "form-editor/graffiti.h"
 
 using namespace Guikachu::Resources;
+using namespace Guikachu;
 
 Form::Form (const string& id_)
 {
@@ -43,7 +47,7 @@ Form::~Form ()
     for (set<Widgets::Widget*>::iterator i = widgets.begin ();
 	 i != widgets.end (); i++)
     {
-	ResourceManager::remove_resource ((*i)->get_id ());
+	ResourceManager::unregister_id ((*i)->get_id ());
 	delete (*i);
 	widgets.erase (i);
     }
@@ -65,6 +69,12 @@ Widgets::Widget* Form::create_widget (Widgets::Type type)
     case Widgets::WIDGET_LABEL:
 	prefix = "label";
 	break;
+    case Widgets::WIDGET_BUTTON:
+	prefix = "button";
+	break;
+    case Widgets::WIDGET_GRAFFITI:
+	prefix = "graffiti";
+	break;
     }
     
     return create_widget (type, ResourceManager::create_id (prefix));
@@ -73,28 +83,55 @@ Widgets::Widget* Form::create_widget (Widgets::Type type)
 Widgets::Widget* Form::create_widget (Widgets::Type type,
 				      const string& id)
 {
-    if (!ResourceManager::register_resource (id))
+    if (!ResourceManager::register_id (id))
 	return 0;
 	
-    Widgets::Widget *res = 0;
+    Widgets::Widget *widget = 0;
 
     switch (type)
     {
     case Widgets::WIDGET_LABEL:
-	res = new Widgets::Label (this, id);
+	widget = new Widgets::Label (this, id);
 	break;
+    case Widgets::WIDGET_BUTTON:
+	widget = new Widgets::Button (this, id);
+	break;
+    case Widgets::WIDGET_GRAFFITI:
+	widget = new Widgets::Graffiti (this, id);
     }
     
-    widgets.insert (res);
-
-#if 0
-    res->changed.connect (SigC::slot (&ResourceManager::resource_changed_cb));
-    dirty = true;
+    widgets.insert (widget);
+    widget->changed.connect (widget_changed.slot());
     
-    resource_created (res);
-#endif
+    widget_created (widget);
 
     changed ();
     
-    return res;
+    return widget;
+}
+
+void Form::remove_widget (Widgets::Widget *widget)
+{
+    widget_removed.emit (widget);
+
+    widgets.erase (widget);
+    ResourceManager::unregister_id (widget->get_id ());
+    
+    delete widget;
+
+    changed ();
+}
+
+Widgets::Widget* Form::get_widget (const string& id) const
+{
+    set<Widgets::Widget*>::const_iterator found;
+
+    found = widgets.begin ();
+    while (found != widgets.end () && (*found)->get_id () != id)
+	found++;
+
+    if (found == widgets.end ())
+	return 0;
+    else
+	return (*found);
 }
