@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.4 2001/03/23 15:14:46 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.8 2001/04/21 13:02:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,22 +50,33 @@ namespace Guikachu
 	    virtual void show_ui ();
 
 	    GUIKACHU_RESOURCE_PROP(title,	string);
+
 	    GUIKACHU_RESOURCE_PROP(help_id,	string);
 	    GUIKACHU_RESOURCE_PROP(menu_id,	string);
+	    
 	    GUIKACHU_RESOURCE_PROP(modal,	bool);
 	    GUIKACHU_RESOURCE_PROP(frame,	bool);
 	    GUIKACHU_RESOURCE_PROP(savebehind,	bool);
+
+	    GUIKACHU_RESOURCE_PROP(def_button,  string);
+	    
 	    GUIKACHU_RESOURCE_PROP(x,		int);
 	    GUIKACHU_RESOURCE_PROP(y,		int);
 	    GUIKACHU_RESOURCE_PROP(width,	int);
 	    GUIKACHU_RESOURCE_PROP(height,	int);
 
 	    const set<Widgets::Widget*>& get_widgets () const { return widgets; };
+	    Widgets::Widget*             get_widget (const string& id) const;
 	    
 	    // Widget managment
 	    Widgets::Widget* create_widget (Widgets::Type type,
 					    const string& id);
 	    Widgets::Widget* create_widget (Widgets::Type type);
+	    void remove_widget (Widgets::Widget *widget);
+	    
+	    SigC::Signal1<void, Widgets::Widget*> widget_created;
+	    SigC::Signal1<void, Widgets::Widget*> widget_removed;
+	    SigC::Signal0<void> widget_changed;
 	private:
 	    // Persistance
 	    virtual bool load (xmlDocPtr doc, xmlNodePtr node);
