@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.5 2001/03/23 15:14:46 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.9 2001/04/04 16:11:22 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -55,27 +55,33 @@ namespace Guikachu
 	    FormEditor::Form    *form;
 
 	    Gtk::Tooltips        tips;
-	    
+
+	    Widgets::Widget     *edited_widget;
 	public:
 	    FormWindow (Resources::Form *res);
 	    ~FormWindow ();
 	    void show ();
-
-	    void show_property_editor (Gtk::Widget *widget);
+	    
 	    Gnome::Canvas *get_canvas () const { return canvas; };
 	private:
 	    void create_palette ();
-	    
+
+	    void show_property_editor (Widgets::Widget *widget);
+	    void show_form_property_editor ();
+
 	    int delete_event_impl (GdkEventAny *e);
 	    int property_delete_event_impl (GdkEventAny *e);
 	    void update ();
 
-	    void add_widget_cb (Resources::Widgets::Type type);
+	    void add_widget_cb (Widgets::Type type);
 
+	    void widget_created_cb (Widgets::Widget *widget);
+	    void widget_removed_cb (Widgets::Widget *widget);
+	    
 	    void toplevel_activate_cb ();
-	    void widget_activate_cb (Resources::Widgets::Widget *widget);
+	    void widget_activate_cb (Widgets::Widget *widget);
 	};
     };
 };
 
-#endif /* !GUIKATCHU_DIALOG_WIN_H */
+#endif /* !GUIKATCHU_FORM_WIN_H */
