@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.3 2001/03/04 14:07:48 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.4 2001/04/01 18:16:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -77,6 +77,12 @@ void GUI::MainWin::new_cb ()
     update_title ();
 }
 
+void GUI::MainWin::set_filename (const string& filename_)
+{
+    filename = filename_;
+    update_title ();
+}
+
 void GUI::MainWin::filesel_close_cb (Gtk::FileSelection *fs)
 {
     delete fs;
