@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.8 2001/03/24 11:50:25 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.10 2001/03/31 21:16:17 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,18 +44,11 @@ GUI::MainWin::MainWin ():
     filename (""),
     in_exit (false)
 {
-    /* Create status bar */
-    set_statusbar (*manage (new Gtk::Statusbar ()));
-    
     using namespace SigC;
     using namespace Gnome;
     
-    /* Create the menu */
-    list <UI::Info> menubar;
-
     /* File menu */
     list <UI::Info> m_file;
-
     m_file.push_back (MenuItems::New    (_("_New project"), _("Create a new project"),
 					 slot (this, &MainWin::new_cb)));
     m_file.push_back (MenuItems::Open   (slot (this, &MainWin::load_cb)));
@@ -68,14 +61,19 @@ GUI::MainWin::MainWin ():
     m_file.push_back (UI::Separator     ());
     m_file.push_back (MenuItems::Exit   (bind (rettype<void>(delete_event.slot()),
 					       (GdkEventAny*)0)));
-    menubar.push_back (Menus::File (m_file));
 
     /* Help menu */
     list <UI::Info> m_help;
     m_help.push_back (MenuItems::About (slot (&show_about)));
+
+    /* Create the menu */
+    list <UI::Info> menubar;    
+    menubar.push_back (Menus::File (m_file));
     menubar.push_back (Menus::Help (m_help));
-    
     create_menus (menubar);
+
+    /* Create status bar */
+    set_statusbar (*manage (new Gtk::Statusbar ()));
     install_menu_hints ();
 
     /* Create the tool bar */
@@ -119,10 +117,16 @@ GUI::MainWin::MainWin ():
 
     /* Create subtrees */
     create_tree_for_type (Resources::RESOURCE_DIALOG, _("Dialogs"));
-    create_tree_for_type (Resources::RESOURCE_FORM, _("Forms"));
-    create_tree_for_type (Resources::RESOURCE_MENU, _("Menus"));
+    create_tree_for_type (Resources::RESOURCE_FORM,   _("Forms"));
+    create_tree_for_type (Resources::RESOURCE_MENU,   _("Menus"));
     create_tree_for_type (Resources::RESOURCE_STRING, _("Strings"));
 
+    /* Fill with existing resources */
+    set<Resources::Resource*> resources = ResourceManager::get_resources ();
+    for (set<Resources::Resource*>::iterator i = resources.begin ();
+	 i != resources.end (); i++)
+	resource_created_cb ((*i));
+    
     /* Connect to Resource Manager signals */
     ResourceManager::resource_created.connect (slot (this, &MainWin::resource_created_cb));
     ResourceManager::resource_removed.connect (slot (this, &MainWin::resource_removed_cb));
