@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.6 2001/03/24 11:50:25 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.9 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,11 +22,13 @@
 #include <libgnome/libgnome.h>
 
 #include <sigc++/retbind.h>
+#include "argumentsink.h"
 
 using namespace Guikachu;
 
 GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
-    res (res_)
+    res (res_),
+    update_block (false)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", NULL);
 
@@ -59,15 +61,15 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     item_shortcut = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "menuitem_shortcut")));
     lbl_item_shortcut = wrap (GTK_LABEL (glade_xml_get_widget (gui, "menuitem_shortcut_label")));
 
-    id_entry->activate.connect (bind (slot (this, &MenuWindow::id_entry_cb), (GdkEventFocus*) 0));
-    id_entry->focus_out_event.connect (retbind (slot (this, &MenuWindow::id_entry_cb), 0));
+    id_entry->activate.connect (slot (this, &MenuWindow::id_entry_cb));
+    id_entry->focus_out_event.connect (
+	hide<int, GdkEventFocus*> (retbind (slot (this, &MenuWindow::id_entry_cb),0)));
 
-    item_id->activate.connect (bind (slot (this, &MenuWindow::item_id_entry_cb), (GdkEventFocus*) 0));
-    item_id->focus_out_event.connect (retbind (slot (this, &MenuWindow::item_id_entry_cb), 0));
-    item_label->activate.connect (bind (slot (this, &MenuWindow::item_label_entry_cb), (GdkEventFocus*) 0));
-    item_label->focus_out_event.connect (retbind (slot (this, &MenuWindow::item_label_entry_cb), 0));
-    item_shortcut->activate.connect (bind (slot (this, &MenuWindow::item_shortcut_entry_cb), (GdkEventFocus*) 0));
-    item_shortcut->focus_out_event.connect (retbind (slot (this, &MenuWindow::item_shortcut_entry_cb), 0));
+    item_id->activate.connect (slot (this, &MenuWindow::item_id_entry_cb));
+    item_id->focus_out_event.connect (
+	hide<int, GdkEventFocus*> (retbind (slot (this, &MenuWindow::item_id_entry_cb),0)));
+    item_label->changed.connect (slot (this, &MenuWindow::item_label_entry_cb));
+    item_shortcut->changed.connect (slot (this, &MenuWindow::item_shortcut_entry_cb));
 
     btnUp->clicked.connect (slot (this, &MenuWindow::btn_up_cb));
     btnDown->clicked.connect (slot (this, &MenuWindow::btn_down_cb));
@@ -103,6 +105,8 @@ void GUI::MenuWindow::show ()
 
 void GUI::MenuWindow::update ()
 {
+    update_block = true;
+    
     gchar *title_buf = g_strdup_printf (_("Menu: %s"), res->get_id ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
@@ -170,6 +174,8 @@ void GUI::MenuWindow::update ()
     }
 
     clist->select_row (selected_row);
+
+    update_block = false;
 }
 
 void GUI::MenuWindow::reset_controls ()
@@ -197,6 +203,8 @@ void GUI::MenuWindow::reset_controls ()
 void GUI::MenuWindow::clist_sel_row (gint row, gint column,
 				     GdkEvent *event)
 {
+    update_block = true;
+    
     RowData& row_data = clist_rows[row];
 
     if (clist->selection ().size () != 1)
@@ -247,14 +255,16 @@ void GUI::MenuWindow::clist_sel_row (gint row, gint column,
 	    g_free (shortcut_str);
 	}
     }
+
+    update_block = false;
 }
 
-void GUI::MenuWindow::id_entry_cb (GdkEventFocus *e)
+void GUI::MenuWindow::id_entry_cb ()
 {
     res->set_id (id_entry->get_text ());
 }
 
-void GUI::MenuWindow::item_id_entry_cb (GdkEventFocus *e)
+void GUI::MenuWindow::item_id_entry_cb ()
 {
     if (clist->selection ().size () != 1)
 	return;
@@ -271,11 +281,16 @@ void GUI::MenuWindow::item_id_entry_cb (GdkEventFocus *e)
     res->set_submenus (submenus);
 }
 
-void GUI::MenuWindow::item_label_entry_cb (GdkEventFocus *e)
+void GUI::MenuWindow::item_label_entry_cb ()
 {
+    if (update_block)
+	return;
+    
     if (clist->selection ().size () != 1)
 	return;
 
+    int saved_pos = item_label->get_position ();
+    
     unsigned int row = clist->selection ().begin ()->get_row_num ();
     unsigned int index = clist_rows[row].index;
 
@@ -292,10 +307,16 @@ void GUI::MenuWindow::item_label_entry_cb (GdkEventFocus *e)
 	
 	res->set_submenus (submenus);
     }
+
+    item_label->set_position (saved_pos);
+    item_label->grab_focus ();
 }
 
-void GUI::MenuWindow::item_shortcut_entry_cb (GdkEventFocus *e)
+void GUI::MenuWindow::item_shortcut_entry_cb ()
 {
+    if (update_block)
+	return;
+    
     if (clist->selection ().size () != 1)
 	return;
 
@@ -313,7 +334,9 @@ void GUI::MenuWindow::item_shortcut_entry_cb (GdkEventFocus *e)
     else
 	items[index].shortcut = shortcut_str[0];
 
-    res->set_submenus (submenus);    
+    res->set_submenus (submenus);
+    
+    item_shortcut->grab_focus ();
 }
 
 void GUI::MenuWindow::btn_up_cb ()
