@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.6 2001/03/18 14:18:39 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.8 2001/04/15 13:03:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,10 +25,10 @@
 #include <sigc++/basic_signal.h>
 
 #define GUIKACHU_RESOURCE_PROP(param,type)			\
-	private:						\
+	protected:						\
 	    type param;						\
 	public:							\
-	    type get_##param () const { return param; };	\
+	    type get_##param () { return param; };		\
 	    void set_##param (const type & param##_) { param = param##_; changed (); };
 
 namespace Guikachu
@@ -53,7 +53,7 @@ namespace Guikachu
 {
     namespace Resources
     {
-	class Resource
+	class Resource: public SigC::Object
 	{
 	protected:
 	    string id;
@@ -63,7 +63,7 @@ namespace Guikachu
 	    // Resource managment functions
 	    virtual Type get_type () const = 0;
 
-	    string get_id () const;
+	    string get_id ();
 	    void   set_id (const string& id);
 
 	    SigC::Signal0<void> changed;
