@@ -1,4 +1,4 @@
-//$Id: string-res.cc,v 1.3 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: string-res.cc,v 1.4 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,6 +18,8 @@
 
 #include "string-res.h"
 
+#include <gnome-xml/xmlmemory.h>
+
 using namespace Guikachu;
 
 Resources::String::String (const string& id_)
@@ -59,7 +61,7 @@ bool Resources::String::load (xmlDocPtr doc,
 	return false;
     
     text = xml_text;
-    g_free (xml_text);
+    xmlFree (xml_text);
 
     changed ();
     
