@@ -1,4 +1,4 @@
-//$Id: string-win.cc,v 1.4 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: string-win.cc,v 1.6 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <libgnome/libgnome.h>
 
 #include <sigc++/retbind.h>
+#include "argumentsink.h"
 
 using namespace Guikachu;
 
@@ -39,9 +40,10 @@ GUI::StringWindow::StringWindow (Guikachu::Resources::String *res_):
     id_entry = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "str_name")));
     text_entry = wrap (GTK_TEXT (glade_xml_get_widget (gui, "str_text")));
     
-    id_entry->activate.connect (bind (slot (this, &StringWindow::id_entry_cb), (GdkEventFocus*) 0));
-    id_entry->focus_out_event.connect (retbind (slot (this, &StringWindow::id_entry_cb), 0));
-
+    id_entry->activate.connect (slot (this, &StringWindow::id_entry_cb));
+    id_entry->focus_out_event.connect (
+	hide<int, GdkEventFocus*> (retbind (slot (this, &StringWindow::id_entry_cb),0)));
+    
     text_entry->changed.connect (slot (this, &StringWindow::text_entry_cb));
     text_entry->set_word_wrap (true);
     
@@ -86,7 +88,7 @@ void GUI::StringWindow::update ()
     block_text_entry_cb = false;
 }
 
-void GUI::StringWindow::id_entry_cb (GdkEventFocus *e)
+void GUI::StringWindow::id_entry_cb ()
 {
     res->set_id (id_entry->get_text ());
 }
@@ -94,9 +96,9 @@ void GUI::StringWindow::id_entry_cb (GdkEventFocus *e)
 void GUI::StringWindow::text_entry_cb ()
 {
     if (block_text_entry_cb)
-    {
 	return;
-    }
 
+    int saved_pos = text_entry->get_position ();
     res->set_text (text_entry->get_chars (0, text_entry->get_length ()));
+    gtk_editable_set_position (GTK_EDITABLE (text_entry->gtkobj ()), saved_pos);
 }
